<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $start_time = microtime(true); // Start time to calculate response time
    $email = $_POST['email'];
    $signal_type = isset($_POST['signal_type']) ? strtolower(trim($_POST['signal_type'])) : ''; // Normalize signal_type to lowercase and trim spaces

    // Check if email is provided
    if (empty($email)) {
        echo json_encode(["status" => "error", "message" => "Email is required."]);
        exit();
    }

    // Check if the email exists and retrieve the user details including user_type, plan_duration, telegram_username, etc.
    $sql = "SELECT user_type, name, COALESCE(plan_duration, '0011') AS plan_duration, 
                   COALESCE(telegram_username, '0011') AS telegram_username, 
                   user_status 
            FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        echo json_encode(["status" => "error", "message" => "User not found."]);
    } else {
        $user = $result->fetch_assoc();
        if ($user['user_status'] != 'active') {
            echo json_encode(["status" => "error", "message" => "User banned by admin."]);
        } else {
            // Fetch the plan details based on user_type from the Plans table
            $user_type = $user['user_type'];
            $sql_plan = "SELECT plan_name, plan_type FROM Plans WHERE plan_name = ?";
            $stmt_plan = $conn->prepare($sql_plan);
            $stmt_plan->bind_param("s", $user_type);
            $stmt_plan->execute();
            $result_plan = $stmt_plan->get_result();

            if ($result_plan->num_rows > 0) {
                $plan = $result_plan->fetch_assoc();
                $plan_name = $plan['plan_name'];
                $plan_type = $plan['plan_type']; // Fetch the plan_type value for user_purchase_plan
            } else {
                $plan_name = '0011'; // Default value if no match found
                $plan_type = '0011'; // Default value if no match found
            }

            // Validate the signal_type
            if ($signal_type === 'expired') {
                // Fetch all expired signals
                $sql = "SELECT * FROM ExpiredSignals";
                $result = $conn->query($sql);

                if ($result->num_rows > 0) {
                    $signals = [];
                    while ($row = $result->fetch_assoc()) {
                        $signals[] = $row;
                    }
                    // End time to calculate response time
                    $end_time = microtime(true);
                    $response_time = $end_time - $start_time; // Calculate response time

                    // Send the response with signals and user data, applying default "0011" if any new field is null
                    echo json_encode([
                        "status" => "success",
                        "signals" => $signals,
                        "user_info" => [
                            "name" => $user['name'],
                            "plan_duration" => $user['plan_duration'],
                            "telegram_username" => $user['telegram_username'],
                            "user_status" => $user['user_status'],
                            "plan_name" => $plan_name,
                            "user_purchase_plan" => $plan_type // Add user_purchase_plan from plan_type
                        ],
                    ]);
                } else {
                    echo json_encode(["status" => "error", "message" => "No expired signals found."]);
                }
            } else {
                echo json_encode(["status" => "error", "message" => "Invalid signal type."]);
            }

            // Close the statement for plan query
            $stmt_plan->close();
        }
    }

    // Close the statement and connection
    $stmt->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
