<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];

    // Check if the email field is empty
    if (empty($email)) {
        echo json_encode(["status" => "error", "message" => "Email is required."]);
        exit();
    }

    // Check if email exists
    $sql = "SELECT user_status FROM Users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        echo json_encode(["status" => "error", "message" => "Email not registered."]);
    } else {
        $user = $result->fetch_assoc();

        // Check user status
        if ($user['user_status'] !== 'active') {
            echo json_encode(["status" => "error", "message" => "Your account is banned by admin. Please contact support."]);
        } else {
            // Fetch all posts if the user is active
            $postsSql = "SELECT * FROM Posts ORDER BY created_at DESC"; // Latest posts first
            $postsResult = $conn->query($postsSql);

            $posts = array();
            while ($post = $postsResult->fetch_assoc()) {
                $posts[] = $post;
            }

            // Return posts as JSON
            echo json_encode(["status" => "success", "posts" => $posts]);
        }
    }

    // Close the statement and connection
    $stmt->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
