<?php
// Include the database connection file
include '../../includes/connection.php';

// Check if the required data is sent via POST
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];

    // Check if email field is empty
    if (empty($email)) {
        echo json_encode(["status" => "error", "message" => "Email is required."]);
        exit();
    }

    // Check if email exists in the Users table
    $sql = "SELECT 
                name, 
                email, 
                user_type, 
                plan_duration, 
                purchase_date, 
                expired_date, 
                telegram_username, 
                user_status 
            FROM 
                Users 
            WHERE 
                email = ?";
    
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows == 0) {
        echo json_encode(["status" => "error", "message" => "Email not registered."]);
    } else {
        $user = $result->fetch_assoc();
        
        // Check if the user status is active
        if ($user['user_status'] != 'active') {
            echo json_encode(["status" => "error", "message" => "Your account has been banned by the admin."]);
        } else {
            // User is valid; fetch settings data
            $sql_settings = "SELECT facebook_link, telegram_link, support_email FROM Settings";
            $stmt_settings = $conn->prepare($sql_settings);
            $stmt_settings->execute();
            $result_settings = $stmt_settings->get_result();

            $settings = $result_settings->fetch_assoc();

            // Prepare the final response
            echo json_encode([
                "status" => "success",
                "data" => [
                    "name" => $user['name'],
                    "email" => $user['email'],
                    "user_type" => $user['user_type'],
                    "plan_duration" => $user['plan_duration'],
                    "purchase_date" => $user['purchase_date'],
                    "expired_date" => $user['expired_date'],
                    "telegram_username" => $user['telegram_username'],
                    "user_status" => $user['user_status'],
                    "facebook_link" => $settings['facebook_link'],
                    "support_email" => $settings['support_email'],
                    "telegram_link" => $settings['telegram_link'] 
                ]
            ]);
        }
    }

    // Close the statements and connection
    $stmt->close();
    $stmt_settings->close();
    $conn->close();
} else {
    echo json_encode(["status" => "error", "message" => "Invalid request method."]);
}
?>
