<?php

// Include the database connection file
include '../../includes/connection.php';

// Initialize an array to store the results
$responseData = array(
    'updated_users' => array(),
    // 'no_update_needed' => array(),
    'new_users' => array()
);

// Fetch the Telegram Bot Token from the Settings table
$botToken = '';
$tokenStmt = $conn->prepare("SELECT telegram_bot_token FROM Settings LIMIT 1");
$tokenStmt->execute();
$tokenResult = $tokenStmt->get_result();

if ($tokenResult->num_rows > 0) {
    $row = $tokenResult->fetch_assoc();
    $botToken = $row['telegram_bot_token'];
}

$tokenStmt->close();

if (empty($botToken)) {
    die(json_encode(array('error' => 'Bot token not found in the database.')));
}

// Get updates from Telegram
$url = "https://api.telegram.org/bot$botToken/getUpdates";
$response = file_get_contents($url);
$updates = json_decode($response, true);

if (isset($updates['result'])) {
    foreach ($updates['result'] as $update) {
        $username = '';
        $chat_id = '';

        // Check for different types of updates
        if (isset($update['message'])) {
            // Handle message updates
            $message = $update['message'];
            $chat_id = $message['chat']['id'];
            $username = isset($message['from']['username']) ? $message['from']['username'] : '';
        } elseif (isset($update['my_chat_member'])) {
            // Handle my_chat_member updates
            $myChatMember = $update['my_chat_member'];
            $chat_id = $myChatMember['chat']['id'];
            $username = isset($myChatMember['from']['username']) ? $myChatMember['from']['username'] : '';
        }

        // Proceed only if a username is found
        if (!empty($username) && !empty($chat_id)) {
            // Check if the username exists in the database
            $stmt = $conn->prepare("SELECT telegram_chat_id FROM Users WHERE telegram_username = ?");
            $stmt->bind_param("s", $username);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                // User exists, check chat_id
                $row = $result->fetch_assoc();
                $existing_chat_id = $row['telegram_chat_id'];

                // Check if chat_id is null, blank, or doesn't match
                if (empty($existing_chat_id) || $existing_chat_id != $chat_id) {
                    // Update the chat_id in the database
                    $updateStmt = $conn->prepare("UPDATE Users SET telegram_chat_id = ? WHERE telegram_username = ?");
                    $updateStmt->bind_param("ss", $chat_id, $username);
                    $updateStmt->execute();
                    $updateStmt->close();

                    // Add the updated user to the response data
                    $responseData['updated_users'][] = array(
                        'username' => $username,
                        'chat_id' => $chat_id
                    );
                } else {
                    // No update needed
                    // $responseData['no_update_needed'][] = array(
                    //     'username' => $username,
                    //     'chat_id' => $chat_id
                    // );
                }
            } else {
                // New user not in the database
                $responseData['new_users'][] = array(
                    'username' => $username,
                    'chat_id' => $chat_id
                );
            }

            $stmt->close();
        }
    }
}

// Output the result as JSON
header('Content-Type: application/json');
echo json_encode($responseData, JSON_PRETTY_PRINT);

// Close the database connection
$conn->close();
?>
