<?php
// Include the database connection file
include '../../includes/connection.php';

// Define the default developer number
$default_developer_number = '8801829934805';

// Define email parameters
$api_url = 'https://deentime.app/mail/send.php'; // URL of the mail sending API
$sender_name = 'SigniFX';
$subject = 'Important: Your Subscription Plan Has Expired';
$company_name = 'SigniFX';

// Function to send email using the external API
function send_email_via_api($receiver_email, $subject, $message) {
    global $api_url, $sender_name;

    // Prepare the request parameters
    $params = [
        'sender_name' => $sender_name,
        'subject' => $subject,
        'receiver_email' => $receiver_email,
        'message' => $message
    ];

    // Build query string from parameters
    $query = http_build_query($params);

    // Send HTTP GET request
    $response = file_get_contents($api_url . '?' . $query);

    // Check the response
    return $response !== false;
}

// Check if developer_number parameter is provided and matches the default
if (!isset($_GET['developer_number']) || $_GET['developer_number'] !== $default_developer_number) {
    header('Content-Type: application/json');
    echo json_encode([
        'status' => 'error',
        'message' => 'Invalid or missing developer number.'
    ], JSON_PRETTY_PRINT);
    exit();
}

// Check the connection
if ($conn->connect_error) {
    header('Content-Type: application/json');
    echo json_encode([
        'status' => 'error',
        'message' => 'Connection failed: ' . $conn->connect_error
    ], JSON_PRETTY_PRINT);
    exit();
}

// Get today's date in YYYY-MM-DD format
$current_date = date("Y-m-d");

// SQL query to select users whose expired_date is before today's date and plan_duration is not 0
$select_sql = "SELECT id, name, email, plan_duration
               FROM Users
               WHERE expired_date < ? AND plan_duration != 0";

// Prepare and execute the select statement
$stmt = $conn->prepare($select_sql);
$stmt->bind_param("s", $current_date);
$stmt->execute();
$result = $stmt->get_result();

// Fetch affected users
$affected_users = [];
while ($row = $result->fetch_assoc()) {
    $affected_users[] = $row;
}

// If there are users to update
if (count($affected_users) > 0) {
    // SQL query to update users whose plan_duration is not 0
    $update_sql = "UPDATE Users
                   SET purchase_date = NULL,
                       plan_duration = NULL,
                       expired_date = NULL,
                       user_type = NULL
                   WHERE expired_date < ? AND plan_duration != 0";

    // Prepare and bind
    $update_stmt = $conn->prepare($update_sql);
    $update_stmt->bind_param("s", $current_date);
    
    // Execute the update statement
    if ($update_stmt->execute()) {
        // Send emails to affected users
        foreach ($affected_users as $user) {
            $name = $user['name'];
            $email = $user['email'];
            $message = "
                <html>
                <head>
                    <style>
                        body {
                            font-family: Arial, sans-serif;
                            color: #333;
                            line-height: 1.6;
                            margin: 20px;
                        }
                        .container {
                            max-width: 600px;
                            margin: 0 auto;
                            padding: 20px;
                            border: 1px solid #ddd;
                            border-radius: 5px;
                            background-color: #f9f9f9;
                        }
                        h1 {
                            color: #0056b3;
                        }
                        p {
                            margin: 10px 0;
                        }
                        .footer {
                            margin-top: 20px;
                            font-size: 0.9em;
                            color: #777;
                        }
                        a {
                            color: #0056b3;
                            text-decoration: none;
                        }
                    </style>
                </head>
                <body>
                    <div class='container'>
                        <h1>Hello $name,</h1>
                        <p>We hope this email finds you well.</p>
                        <p>This is a notification from <strong>$company_name</strong> regarding your subscription plan.</p>
                        <p>We want to inform you that your subscription plan has expired as of today. As a result, your account information has been reset.</p>
                        <p>To continue enjoying our services, we encourage you to <a href=''>purchase a new plan</a> at your earliest convenience.</p>
                        <p>Thank you for using our app. If you have any questions or need further assistance, please feel free to reach out to our support team.</p>
                        <p class='footer'>Best regards,<br>The $company_name Team</p>
                    </div>
                </body>
                </html>
            ";

            send_email_via_api($email, $subject, $message);
        }

        header('Content-Type: application/json');
        echo json_encode([
            'status' => 'success',
            'message' => 'User plans have been expired and notification emails have been sent.',
            'affected_users' => $affected_users
        ], JSON_PRETTY_PRINT);
    } else {
        header('Content-Type: application/json');
        echo json_encode([
            'status' => 'error',
            'message' => 'Error updating records: ' . $update_stmt->error
        ], JSON_PRETTY_PRINT);
    }
    
    // Close update statement
    $update_stmt->close();
} else {
    header('Content-Type: application/json');
    echo json_encode([
        'status' => 'info',
        'message' => 'Today no user has expired plans or plan_duration is 0.'
    ], JSON_PRETTY_PRINT);
}

// Close connections
$stmt->close();
$conn->close();
?>
